# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/participant_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/judge/participant_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from eolymp.judge import participant_pb2 as eolymp_dot_judge_dot_participant__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/judge/participant_service.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x18\x65olymp/ecm/content.proto\x1a\x1e\x65olymp/judge/participant.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"\xb7\x01\n\x16\x41ssignParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12.\n\x0bparticipant\x18\x02 \x01(\x0b\x32\x19.eolymp.judge.Participant\x12\x13\n\tmember_id\x18\n \x01(\tH\x00\x12\x12\n\x08group_id\x18\x0b \x01(\tH\x00\x12\x12\n\nunofficial\x18\x14 \x01(\x08\x12\x10\n\x08inactive\x18\x15 \x01(\x08\x42\n\n\x08\x61ssignee\"1\n\x17\x41ssignParticipantOutput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\"D\n\x16\x45nableParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"\x19\n\x17\x45nableParticipantOutput\"E\n\x17\x44isableParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"\x1a\n\x18\x44isableParticipantOutput\"\x9a\x02\n\x16UpdateParticipantInput\x12\x39\n\x05patch\x18\x03 \x03(\x0e\x32*.eolymp.judge.UpdateParticipantInput.Patch\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\x12.\n\x0bparticipant\x18\x04 \x01(\x0b\x32\x19.eolymp.judge.Participant\"i\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x10\n\x0c\x44ISPLAY_NAME\x10\x01\x12\x0e\n\nBONUS_TIME\x10\x03\x12\x0e\n\nUNOFFICIAL\x10\x04\x12\t\n\x05MEDAL\x10\x05\x12\x0c\n\x08INACTIVE\x10\x06\x12\x0c\n\x08PASSCODE\x10\x07\"\x19\n\x17UpdateParticipantOutput\"\x81\x01\n\x1a\x44isqualifyParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\x12\x12\n\ndisqualify\x18\x03 \x01(\x08\x12#\n\x06reason\x18\x04 \x01(\x0b\x32\x13.eolymp.ecm.Content\"\x1d\n\x1b\x44isqualifyParticipantOutput\"D\n\x16\x44\x65leteParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"\x19\n\x17\x44\x65leteParticipantOutput\"F\n\x18\x44\x65scribeParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"K\n\x19\x44\x65scribeParticipantOutput\x12.\n\x0bparticipant\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\"\xe4\x05\n\x15ListParticipantsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06search\x18\x14 \x01(\t\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.judge.ListParticipantsInput.Filter\x12:\n\x04sort\x18\x32 \x01(\x0e\x32,.eolymp.judge.ListParticipantsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\xa8\x03\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x08group_id\x18\x04 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06status\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x39\n\nstarted_at\x18\x06 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x34\n\nunofficial\x18\n \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x36\n\x0c\x64isqualified\x18\x0b \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x32\n\x08inactive\x18\x0c \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"9\n\x08Sortable\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x10\n\x0c\x44ISPLAY_NAME\x10\x01\x12\x0e\n\nSTARTED_AT\x10\x02\"Q\n\x16ListParticipantsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.judge.Participant\"C\n\x15WatchParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x02 \x01(\t\"H\n\x16WatchParticipantOutput\x12.\n\x0bparticipant\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\")\n\x13\x44\x65scribeViewerInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"F\n\x14\x44\x65scribeViewerOutput\x12.\n\x0bparticipant\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\"&\n\x10JoinContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x13\n\x11JoinContestOutput\"\'\n\x11StartContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x14\n\x12StartContestOutput2\xc1\x0f\n\x12ParticipantService\x12\xa1\x01\n\x11\x41ssignParticipant\x12$.eolymp.judge.AssignParticipantInput\x1a%.eolymp.judge.AssignParticipantOutput\"?\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x0f\"\r/participants\x12\xb9\x01\n\x11\x45nableParticipant\x12$.eolymp.judge.EnableParticipantInput\x1a%.eolymp.judge.EnableParticipantOutput\"W\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\'\"%/participants/{participant_id}/enable\x12\xbd\x01\n\x12\x44isableParticipant\x12%.eolymp.judge.DisableParticipantInput\x1a&.eolymp.judge.DisableParticipantOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02(\"&/participants/{participant_id}/disable\x12\xb2\x01\n\x11UpdateParticipant\x12$.eolymp.judge.UpdateParticipantInput\x1a%.eolymp.judge.UpdateParticipantOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02 \x1a\x1e/participants/{participant_id}\x12\xc9\x01\n\x15\x44isqualifyParticipant\x12(.eolymp.judge.DisqualifyParticipantInput\x1a).eolymp.judge.DisqualifyParticipantOutput\"[\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02+\")/participants/{participant_id}/disqualify\x12\xb2\x01\n\x11\x44\x65leteParticipant\x12$.eolymp.judge.DeleteParticipantInput\x1a%.eolymp.judge.DeleteParticipantOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02 *\x1e/participants/{participant_id}\x12\xb8\x01\n\x13\x44\x65scribeParticipant\x12&.eolymp.judge.DescribeParticipantInput\x1a\'.eolymp.judge.DescribeParticipantOutput\"P\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02 \x12\x1e/participants/{participant_id}\x12\x9d\x01\n\x10ListParticipants\x12#.eolymp.judge.ListParticipantsInput\x1a$.eolymp.judge.ListParticipantsOutput\">\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x0f\x12\r/participants\x12{\n\x10WatchParticipant\x12#.eolymp.judge.WatchParticipantInput\x1a$.eolymp.judge.WatchParticipantOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x12{\n\x0e\x44\x65scribeViewer\x12!.eolymp.judge.DescribeViewerInput\x1a\".eolymp.judge.DescribeViewerOutput\"\"\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\r\x12\x0b/introspect\x12l\n\x0bJoinContest\x12\x1e.eolymp.judge.JoinContestInput\x1a\x1f.eolymp.judge.JoinContestOutput\"\x1c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x03\x82\xd3\xe4\x93\x02\x07\"\x05/join\x12\x91\x01\n\x0cStartContest\x12\x1f.eolymp.judge.StartContestInput\x1a .eolymp.judge.StartContestOutput\">\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x03\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\x82\xd3\xe4\x93\x02\x08\"\x06/startB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.participant_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['AssignParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['AssignParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\017\"\r/participants'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['EnableParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['EnableParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\'\"%/participants/{participant_id}/enable'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DisableParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DisableParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002(\"&/participants/{participant_id}/disable'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['UpdateParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['UpdateParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002 \032\036/participants/{participant_id}'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DisqualifyParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DisqualifyParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002+\")/participants/{participant_id}/disqualify'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DeleteParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DeleteParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002 *\036/participants/{participant_id}'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DescribeParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DescribeParticipant']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002 \022\036/participants/{participant_id}'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['ListParticipants']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['ListParticipants']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002\017\022\r/participants'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['WatchParticipant']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['WatchParticipant']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DescribeViewer']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['DescribeViewer']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\r\022\013/introspect'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['JoinContest']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['JoinContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\003\202\323\344\223\002\007\"\005/join'
  _globals['_PARTICIPANTSERVICE'].methods_by_name['StartContest']._loaded_options = None
  _globals['_PARTICIPANTSERVICE'].methods_by_name['StartContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\003\202\343\n\035\212\343\n\031judge:contest:participate\202\323\344\223\002\010\"\006/start'
  _globals['_ASSIGNPARTICIPANTINPUT']._serialized_start=283
  _globals['_ASSIGNPARTICIPANTINPUT']._serialized_end=466
  _globals['_ASSIGNPARTICIPANTOUTPUT']._serialized_start=468
  _globals['_ASSIGNPARTICIPANTOUTPUT']._serialized_end=517
  _globals['_ENABLEPARTICIPANTINPUT']._serialized_start=519
  _globals['_ENABLEPARTICIPANTINPUT']._serialized_end=587
  _globals['_ENABLEPARTICIPANTOUTPUT']._serialized_start=589
  _globals['_ENABLEPARTICIPANTOUTPUT']._serialized_end=614
  _globals['_DISABLEPARTICIPANTINPUT']._serialized_start=616
  _globals['_DISABLEPARTICIPANTINPUT']._serialized_end=685
  _globals['_DISABLEPARTICIPANTOUTPUT']._serialized_start=687
  _globals['_DISABLEPARTICIPANTOUTPUT']._serialized_end=713
  _globals['_UPDATEPARTICIPANTINPUT']._serialized_start=716
  _globals['_UPDATEPARTICIPANTINPUT']._serialized_end=998
  _globals['_UPDATEPARTICIPANTINPUT_PATCH']._serialized_start=893
  _globals['_UPDATEPARTICIPANTINPUT_PATCH']._serialized_end=998
  _globals['_UPDATEPARTICIPANTOUTPUT']._serialized_start=1000
  _globals['_UPDATEPARTICIPANTOUTPUT']._serialized_end=1025
  _globals['_DISQUALIFYPARTICIPANTINPUT']._serialized_start=1028
  _globals['_DISQUALIFYPARTICIPANTINPUT']._serialized_end=1157
  _globals['_DISQUALIFYPARTICIPANTOUTPUT']._serialized_start=1159
  _globals['_DISQUALIFYPARTICIPANTOUTPUT']._serialized_end=1188
  _globals['_DELETEPARTICIPANTINPUT']._serialized_start=1190
  _globals['_DELETEPARTICIPANTINPUT']._serialized_end=1258
  _globals['_DELETEPARTICIPANTOUTPUT']._serialized_start=1260
  _globals['_DELETEPARTICIPANTOUTPUT']._serialized_end=1285
  _globals['_DESCRIBEPARTICIPANTINPUT']._serialized_start=1287
  _globals['_DESCRIBEPARTICIPANTINPUT']._serialized_end=1357
  _globals['_DESCRIBEPARTICIPANTOUTPUT']._serialized_start=1359
  _globals['_DESCRIBEPARTICIPANTOUTPUT']._serialized_end=1434
  _globals['_LISTPARTICIPANTSINPUT']._serialized_start=1437
  _globals['_LISTPARTICIPANTSINPUT']._serialized_end=2177
  _globals['_LISTPARTICIPANTSINPUT_FILTER']._serialized_start=1694
  _globals['_LISTPARTICIPANTSINPUT_FILTER']._serialized_end=2118
  _globals['_LISTPARTICIPANTSINPUT_SORTABLE']._serialized_start=2120
  _globals['_LISTPARTICIPANTSINPUT_SORTABLE']._serialized_end=2177
  _globals['_LISTPARTICIPANTSOUTPUT']._serialized_start=2179
  _globals['_LISTPARTICIPANTSOUTPUT']._serialized_end=2260
  _globals['_WATCHPARTICIPANTINPUT']._serialized_start=2262
  _globals['_WATCHPARTICIPANTINPUT']._serialized_end=2329
  _globals['_WATCHPARTICIPANTOUTPUT']._serialized_start=2331
  _globals['_WATCHPARTICIPANTOUTPUT']._serialized_end=2403
  _globals['_DESCRIBEVIEWERINPUT']._serialized_start=2405
  _globals['_DESCRIBEVIEWERINPUT']._serialized_end=2446
  _globals['_DESCRIBEVIEWEROUTPUT']._serialized_start=2448
  _globals['_DESCRIBEVIEWEROUTPUT']._serialized_end=2518
  _globals['_JOINCONTESTINPUT']._serialized_start=2520
  _globals['_JOINCONTESTINPUT']._serialized_end=2558
  _globals['_JOINCONTESTOUTPUT']._serialized_start=2560
  _globals['_JOINCONTESTOUTPUT']._serialized_end=2579
  _globals['_STARTCONTESTINPUT']._serialized_start=2581
  _globals['_STARTCONTESTINPUT']._serialized_end=2620
  _globals['_STARTCONTESTOUTPUT']._serialized_start=2622
  _globals['_STARTCONTESTOUTPUT']._serialized_end=2642
  _globals['_PARTICIPANTSERVICE']._serialized_start=2645
  _globals['_PARTICIPANTSERVICE']._serialized_end=4630
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/commerce/address.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/commerce/address.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/commerce/address.proto\x12\x0f\x65olymp.commerce\"p\n\x07\x41\x64\x64ress\x12\x10\n\x07\x63ountry\x18\xc8\x01 \x01(\t\x12\x0e\n\x05state\x18\xc9\x01 \x01(\t\x12\x14\n\x0bpostal_code\x18\xca\x01 \x01(\t\x12\r\n\x04\x63ity\x18\xcb\x01 \x01(\t\x12\x0e\n\x05line1\x18\xd2\x01 \x01(\t\x12\x0e\n\x05line2\x18\xd3\x01 \x01(\tB3Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.address_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _globals['_ADDRESS']._serialized_start=50
  _globals['_ADDRESS']._serialized_end=162
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/auth/sso_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/auth/sso_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/auth/sso_service.proto\x12\x0b\x65olymp.auth\x1a\"eolymp/annotations/ratelimit.proto\"\xac\x01\n\x15\x41uthorizeRequestInput\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63ode_challenge\x18\x02 \x01(\t\x12\x1d\n\x15\x63ode_challenge_method\x18\x03 \x01(\t\x12\x14\n\x0credirect_uri\x18\x04 \x01(\t\x12\x15\n\rresponse_type\x18\x05 \x01(\t\x12\r\n\x05scope\x18\x06 \x01(\t\x12\r\n\x05state\x18\x07 \x01(\t\".\n\x16\x41uthorizeRequestOutput\x12\x14\n\x0credirect_uri\x18\x01 \x01(\t\"5\n\x16\x41uthorizeCallbackInput\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\"/\n\x17\x41uthorizeCallbackOutput\x12\x14\n\x0credirect_uri\x18\x01 \x01(\t2\xeb\x01\n\nSSOService\x12l\n\x10\x41uthorizeRequest\x12\".eolymp.auth.AuthorizeRequestInput\x1a#.eolymp.auth.AuthorizeRequestOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x12o\n\x11\x41uthorizeCallback\x12#.eolymp.auth.AuthorizeCallbackInput\x1a$.eolymp.auth.AuthorizeCallbackOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2B+Z)github.com/eolymp/go-sdk/eolymp/auth;authb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.auth.sso_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/eolymp/go-sdk/eolymp/auth;auth'
  _globals['_SSOSERVICE'].methods_by_name['AuthorizeRequest']._loaded_options = None
  _globals['_SSOSERVICE'].methods_by_name['AuthorizeRequest']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2'
  _globals['_SSOSERVICE'].methods_by_name['AuthorizeCallback']._loaded_options = None
  _globals['_SSOSERVICE'].methods_by_name['AuthorizeCallback']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2'
  _globals['_AUTHORIZEREQUESTINPUT']._serialized_start=83
  _globals['_AUTHORIZEREQUESTINPUT']._serialized_end=255
  _globals['_AUTHORIZEREQUESTOUTPUT']._serialized_start=257
  _globals['_AUTHORIZEREQUESTOUTPUT']._serialized_end=303
  _globals['_AUTHORIZECALLBACKINPUT']._serialized_start=305
  _globals['_AUTHORIZECALLBACKINPUT']._serialized_end=358
  _globals['_AUTHORIZECALLBACKOUTPUT']._serialized_start=360
  _globals['_AUTHORIZECALLBACKOUTPUT']._serialized_end=407
  _globals['_SSOSERVICE']._serialized_start=410
  _globals['_SSOSERVICE']._serialized_end=645
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/discussion/post_type.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/discussion/post_type.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/discussion/post_type.proto\x12\x11\x65olymp.discussion\"\xcd\x01\n\x08PostType\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06hidden\x18\x03 \x01(\x08\x12\r\n\x05order\x18\n \x01(\x05\x12\x35\n\x08variants\x18\x64 \x03(\x0b\x32#.eolymp.discussion.PostType.Variant\x1a\'\n\x07Variant\x12\x0e\n\x06locale\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"(\n\x05\x45xtra\x12\x11\n\rUNKNOWN_EXTRA\x10\x00\x12\x0c\n\x08VARIANTS\x10\x01\x42\x37Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.post_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _globals['_POSTTYPE']._serialized_start=57
  _globals['_POSTTYPE']._serialized_end=262
  _globals['_POSTTYPE_VARIANT']._serialized_start=181
  _globals['_POSTTYPE_VARIANT']._serialized_end=220
  _globals['_POSTTYPE_EXTRA']._serialized_start=222
  _globals['_POSTTYPE_EXTRA']._serialized_end=262
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.feed import entry_pb2 as _entry_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListEntriesInput(_message.Message):
    __slots__ = ("size", "after")
    SIZE_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    size: int
    after: str
    def __init__(self, size: _Optional[int] = ..., after: _Optional[str] = ...) -> None: ...

class ListEntriesOutput(_message.Message):
    __slots__ = ("total", "items", "next_page_cursor")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_CURSOR_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_entry_pb2.Entry]
    next_page_cursor: str
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_entry_pb2.Entry, _Mapping]]] = ..., next_page_cursor: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/discussion/message.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/discussion/message.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from eolymp.wellknown import link_pb2 as eolymp_dot_wellknown_dot_link__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65olymp/discussion/message.proto\x12\x11\x65olymp.discussion\x1a\x18\x65olymp/ecm/content.proto\x1a\x1b\x65olymp/wellknown/link.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe2\x03\n\x07Message\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\x12\n\nthread_url\x18\x02 \x01(\t\x12\x11\n\tmember_id\x18\x03 \x01(\t\x12\x10\n\x08reply_to\x18\x04 \x01(\t\x12\x0c\n\x04vote\x18\x0c \x01(\x05\x12\x12\n\nvote_count\x18\n \x01(\x05\x12\x13\n\x0breply_count\x18\x0b \x01(\x05\x12-\n\tposted_at\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tedited_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ndeleted_at\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08revision\x18\r \x01(\x05\x12$\n\x07message\x18\x64 \x01(\x0b\x32\x13.eolymp.ecm.Content\x12&\n\x05links\x18\xc8\x01 \x03(\x0b\x32\x16.eolymp.wellknown.Link\"`\n\x05\x45xtra\x12\x11\n\rUNKNOWN_EXTRA\x10\x00\x12\x11\n\rMESSAGE_VALUE\x10\x01\x12\x12\n\x0eMESSAGE_RENDER\x10\x02\x12\x13\n\x0fMESSAGE_PREVIEW\x10\x03\x12\x08\n\x04VOTE\x10\x04\x42\x37Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _globals['_MESSAGE']._serialized_start=143
  _globals['_MESSAGE']._serialized_end=625
  _globals['_MESSAGE_EXTRA']._serialized_start=529
  _globals['_MESSAGE_EXTRA']._serialized_end=625
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/executor/task_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/executor/task_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.executor import evaluation_task_pb2 as eolymp_dot_executor_dot_evaluation__task__pb2
from eolymp.executor import generation_task_pb2 as eolymp_dot_executor_dot_generation__task__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/executor/task_service.proto\x12\x0f\x65olymp.executor\x1a\"eolymp/annotations/ratelimit.proto\x1a%eolymp/executor/evaluation_task.proto\x1a%eolymp/executor/generation_task.proto\"\x87\x01\n\x0f\x43reateTaskInput\x12\x35\n\nevaluation\x18\x01 \x01(\x0b\x32\x1f.eolymp.executor.EvaluationTaskH\x00\x12\x35\n\ngeneration\x18\x02 \x01(\x0b\x32\x1f.eolymp.executor.GenerationTaskH\x00\x42\x06\n\x04task\"#\n\x10\x43reateTaskOutput\x12\x0f\n\x07task_id\x18\x01 \x01(\t2r\n\x0bTaskService\x12\x63\n\nCreateTask\x12 .eolymp.executor.CreateTaskInput\x1a!.eolymp.executor.CreateTaskOutput\"\x10\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x42\x33Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.task_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _globals['_TASKSERVICE'].methods_by_name['CreateTask']._loaded_options = None
  _globals['_TASKSERVICE'].methods_by_name['CreateTask']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001'
  _globals['_CREATETASKINPUT']._serialized_start=170
  _globals['_CREATETASKINPUT']._serialized_end=305
  _globals['_CREATETASKOUTPUT']._serialized_start=307
  _globals['_CREATETASKOUTPUT']._serialized_end=342
  _globals['_TASKSERVICE']._serialized_start=344
  _globals['_TASKSERVICE']._serialized_end=458
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/submission.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/judge/submission.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.atlas import submission_pb2 as eolymp_dot_atlas_dot_submission__pb2
from eolymp.atlas import testing_feedback_pb2 as eolymp_dot_atlas_dot_testing__feedback__pb2
from eolymp.atlas import testing_scoring_pb2 as eolymp_dot_atlas_dot_testing__scoring__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/judge/submission.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/atlas/submission.proto\x1a#eolymp/atlas/testing_feedback.proto\x1a\"eolymp/atlas/testing_scoring.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa8\t\n\nSubmission\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x07 \x01(\t\x12\x12\n\ncontest_id\x18\x02 \x01(\t\x12\x12\n\nproblem_id\x18\x03 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x04 \x01(\t\x12\x30\n\x0csubmitted_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x64\x65leted\x18\x06 \x01(\x08\x12\x0c\n\x04lang\x18\n \x01(\t\x12\x0e\n\x06source\x18\x0b \x01(\t\x12\x12\n\nsource_url\x18n \x01(\t\x12\x11\n\tsignature\x18\x0c \x01(\t\x12/\n\x06status\x18\x14 \x01(\x0e\x32\x1f.eolymp.atlas.Submission.Status\x12\x31\n\x07verdict\x18\x16 \x01(\x0e\x32 .eolymp.atlas.Submission.Verdict\x12\r\n\x05\x65rror\x18\x15 \x01(\t\x12\x11\n\terror_url\x18\x17 \x01(\t\x12\x0c\n\x04\x63ost\x18\x1e \x01(\x02\x12\r\n\x05score\x18\x1f \x01(\x02\x12\x12\n\npercentage\x18  \x01(\x02\x12.\n\x06groups\x18\x32 \x03(\x0b\x32\x1e.eolymp.judge.Submission.Group\x1a\xf9\x01\n\x03Run\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05index\x18\n \x01(\r\x12\x0f\n\x07test_id\x18\x0b \x01(\t\x12\x0c\n\x04\x63ost\x18\x0c \x01(\x02\x12\r\n\x05score\x18\r \x01(\x02\x12\x17\n\x0fwall_time_usage\x18\x02 \x01(\r\x12\x16\n\x0e\x63pu_time_usage\x18\x03 \x01(\r\x12\x14\n\x0cmemory_usage\x18\x04 \x01(\x04\x12/\n\x06status\x18\x14 \x01(\x0e\x32\x1f.eolymp.atlas.Submission.Status\x12\x31\n\x07verdict\x18\x15 \x01(\x0e\x32 .eolymp.atlas.Submission.Verdict\x1a\x9c\x03\n\x05Group\x12\r\n\x05index\x18\x01 \x01(\r\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12/\n\x06status\x18\n \x01(\x0e\x32\x1f.eolymp.atlas.Submission.Status\x12\x31\n\x07verdict\x18\x0c \x01(\x0e\x32 .eolymp.atlas.Submission.Verdict\x12\x14\n\x0c\x64\x65pendencies\x18\x0b \x03(\r\x12\x0c\n\x04\x63ost\x18\x14 \x01(\x02\x12\r\n\x05score\x18\x15 \x01(\x02\x12/\n\x0cscoring_mode\x18\x16 \x01(\x0e\x32\x19.eolymp.atlas.ScoringMode\x12\x35\n\x0f\x66\x65\x65\x64\x62\x61\x63k_policy\x18\x1e \x01(\x0e\x32\x1c.eolymp.atlas.FeedbackPolicy\x12\x17\n\x0fwall_time_usage\x18) \x01(\r\x12\x16\n\x0e\x63pu_time_usage\x18* \x01(\r\x12\x14\n\x0cmemory_usage\x18. \x01(\x04\x12*\n\x04runs\x18\x64 \x03(\x0b\x32\x1c.eolymp.judge.Submission.Run\"7\n\x05\x45xtra\x12\x0c\n\x08NO_EXTRA\x10\x00\x12\n\n\x06SOURCE\x10\x01\x12\n\n\x06GROUPS\x10\x02\x12\x08\n\x04RUNS\x10\x03\x42-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.submission_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_SUBMISSION']._serialized_start=185
  _globals['_SUBMISSION']._serialized_end=1377
  _globals['_SUBMISSION_RUN']._serialized_start=656
  _globals['_SUBMISSION_RUN']._serialized_end=905
  _globals['_SUBMISSION_GROUP']._serialized_start=908
  _globals['_SUBMISSION_GROUP']._serialized_end=1320
  _globals['_SUBMISSION_EXTRA']._serialized_start=1322
  _globals['_SUBMISSION_EXTRA']._serialized_end=1377
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/judge.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/judge/judge.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.judge import announcement_service_pb2 as eolymp_dot_judge_dot_announcement__service__pb2
from eolymp.judge import contest_service_pb2 as eolymp_dot_judge_dot_contest__service__pb2
from eolymp.judge import participant_service_pb2 as eolymp_dot_judge_dot_participant__service__pb2
from eolymp.judge import passcode_service_pb2 as eolymp_dot_judge_dot_passcode__service__pb2
from eolymp.judge import problem_service_pb2 as eolymp_dot_judge_dot_problem__service__pb2
from eolymp.judge import score_service_pb2 as eolymp_dot_judge_dot_score__service__pb2
from eolymp.judge import submission_service_pb2 as eolymp_dot_judge_dot_submission__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x65olymp/judge/judge.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\'eolymp/judge/announcement_service.proto\x1a\"eolymp/judge/contest_service.proto\x1a&eolymp/judge/participant_service.proto\x1a#eolymp/judge/passcode_service.proto\x1a\"eolymp/judge/problem_service.proto\x1a eolymp/judge/score_service.proto\x1a%eolymp/judge/submission_service.proto2\xcdT\n\x05Judge\x12\x91\x01\n\rCreateContest\x12 .eolymp.judge.CreateContestInput\x1a!.eolymp.judge.CreateContestOutput\";\xea\xe2\n\x0b\xf5\xe2\n\n\xd7\xa3=\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x0b\"\t/contests\x12\x9e\x01\n\rDeleteContest\x12 .eolymp.judge.DeleteContestInput\x1a!.eolymp.judge.DeleteContestOutput\"H\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x18*\x16/contests/{contest_id}\x12\x9e\x01\n\rUpdateContest\x12 .eolymp.judge.UpdateContestInput\x1a!.eolymp.judge.UpdateContestOutput\"H\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x18\x1a\x16/contests/{contest_id}\x12\x89\x01\n\x0f\x44\x65scribeContest\x12\".eolymp.judge.DescribeContestInput\x1a#.eolymp.judge.DescribeContestOutput\"-\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x18\x12\x16/contests/{contest_id}\x12s\n\x0cListContests\x12\x1f.eolymp.judge.ListContestsInput\x1a .eolymp.judge.ListContestsOutput\" \xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x0b\x12\t/contests\x12\x9d\x01\n\x0bOpenContest\x12\x1e.eolymp.judge.OpenContestInput\x1a\x1f.eolymp.judge.OpenContestOutput\"M\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x1d\"\x1b/contests/{contest_id}/open\x12\xa1\x01\n\x0c\x43loseContest\x12\x1f.eolymp.judge.CloseContestInput\x1a .eolymp.judge.CloseContestOutput\"N\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x1e\"\x1c/contests/{contest_id}/close\x12\xa9\x01\n\x0eSuspendContest\x12!.eolymp.judge.SuspendContestInput\x1a\".eolymp.judge.SuspendContestOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02 \"\x1e/contests/{contest_id}/suspend\x12\xa5\x01\n\rFreezeContest\x12 .eolymp.judge.FreezeContestInput\x1a!.eolymp.judge.FreezeContestOutput\"O\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x1f\"\x1d/contests/{contest_id}/freeze\x12\xa5\x01\n\rResumeContest\x12 .eolymp.judge.ResumeContestInput\x1a!.eolymp.judge.ResumeContestOutput\"O\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x1f\"\x1d/contests/{contest_id}/resume\x12\xa7\x01\n\rImportProblem\x12 .eolymp.judge.ImportProblemInput\x1a!.eolymp.judge.ImportProblemOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02!\"\x1f/contests/{contest_id}/problems\x12\xb3\x01\n\x0bSyncProblem\x12\x1e.eolymp.judge.SyncProblemInput\x1a\x1f.eolymp.judge.SyncProblemOutput\"c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x33\"1/contests/{contest_id}/problems/{problem_id}/sync\x12\xb4\x01\n\rUpdateProblem\x12 .eolymp.judge.UpdateProblemInput\x1a!.eolymp.judge.UpdateProblemOutput\"^\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02.\",/contests/{contest_id}/problems/{problem_id}\x12\xa3\x01\n\x0cListProblems\x12\x1f.eolymp.judge.ListProblemsInput\x1a .eolymp.judge.ListProblemsOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00@@\xf8\xe2\n\n\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02!\x12\x1f/contests/{contest_id}/problems\x12\xba\x01\n\x0f\x44\x65scribeProblem\x12\".eolymp.judge.DescribeProblemInput\x1a#.eolymp.judge.DescribeProblemOutput\"^\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02.\x12,/contests/{contest_id}/problems/{problem_id}\x12\xe0\x01\n\x14\x44\x65scribeCodeTemplate\x12\'.eolymp.judge.DescribeCodeTemplateInput\x1a(.eolymp.judge.DescribeCodeTemplateOutput\"u\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x46\x12\x44/contests/{contest_id}/problems/{problem_id}/templates/{template_id}\x12\xd2\x01\n\x12LookupCodeTemplate\x12%.eolymp.judge.LookupCodeTemplateInput\x1a&.eolymp.judge.LookupCodeTemplateOutput\"m\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02>\x12</contests/{contest_id}/problems/{problem_id}/lookup-template\x12\xc1\x01\n\x0eListStatements\x12!.eolymp.judge.ListStatementsInput\x1a\".eolymp.judge.ListStatementsOutput\"h\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x39\x12\x37/contests/{contest_id}/problems/{problem_id}/statements\x12\xc5\x01\n\x0fListAttachments\x12\".eolymp.judge.ListAttachmentsInput\x1a#.eolymp.judge.ListAttachmentsOutput\"i\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02:\x12\x38/contests/{contest_id}/problems/{problem_id}/attachments\x12\xb9\x01\n\x0cListExamples\x12\x1f.eolymp.judge.ListExamplesInput\x1a .eolymp.judge.ListExamplesOutput\"f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x37\x12\x35/contests/{contest_id}/problems/{problem_id}/examples\x12\xb4\x01\n\rDeleteProblem\x12 .eolymp.judge.DeleteProblemInput\x1a!.eolymp.judge.DeleteProblemOutput\"^\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02.*,/contests/{contest_id}/problems/{problem_id}\x12\xbb\x01\n\rRetestProblem\x12 .eolymp.judge.RetestProblemInput\x1a!.eolymp.judge.RetestProblemOutput\"e\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x35\x12\x33/contests/{contest_id}/problems/{problem_id}/retest\x12\xb7\x01\n\x11\x41ssignParticipant\x12$.eolymp.judge.AssignParticipantInput\x1a%.eolymp.judge.AssignParticipantOutput\"U\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02%\"#/contests/{contest_id}/participants\x12\xcf\x01\n\x11\x45nableParticipant\x12$.eolymp.judge.EnableParticipantInput\x1a%.eolymp.judge.EnableParticipantOutput\"m\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02=\";/contests/{contest_id}/participants/{participant_id}/enable\x12\xd3\x01\n\x12\x44isableParticipant\x12%.eolymp.judge.DisableParticipantInput\x1a&.eolymp.judge.DisableParticipantOutput\"n\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02>\"</contests/{contest_id}/participants/{participant_id}/disable\x12\xc8\x01\n\x11UpdateParticipant\x12$.eolymp.judge.UpdateParticipantInput\x1a%.eolymp.judge.UpdateParticipantOutput\"f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x36\x1a\x34/contests/{contest_id}/participants/{participant_id}\x12\xc8\x01\n\x11\x44\x65leteParticipant\x12$.eolymp.judge.DeleteParticipantInput\x1a%.eolymp.judge.DeleteParticipantOutput\"f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x36*4/contests/{contest_id}/participants/{participant_id}\x12\xb3\x01\n\x10ListParticipants\x12#.eolymp.judge.ListParticipantsInput\x1a$.eolymp.judge.ListParticipantsOutput\"T\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02%\x12#/contests/{contest_id}/participants\x12\xce\x01\n\x13\x44\x65scribeParticipant\x12&.eolymp.judge.DescribeParticipantInput\x1a\'.eolymp.judge.DescribeParticipantOutput\"f\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x36\x12\x34/contests/{contest_id}/participants/{participant_id}\x12\x91\x01\n\x0e\x44\x65scribeViewer\x12!.eolymp.judge.DescribeViewerInput\x1a\".eolymp.judge.DescribeViewerOutput\"8\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02#\x12!/contests/{contest_id}/introspect\x12\x82\x01\n\x0bJoinContest\x12\x1e.eolymp.judge.JoinContestInput\x1a\x1f.eolymp.judge.JoinContestOutput\"2\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x03\x82\xd3\xe4\x93\x02\x1d\"\x1b/contests/{contest_id}/join\x12\xa7\x01\n\x0cStartContest\x12\x1f.eolymp.judge.StartContestInput\x1a .eolymp.judge.StartContestOutput\"T\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x03\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\x82\xd3\xe4\x93\x02\x1e\"\x1c/contests/{contest_id}/start\x12\xb0\x01\n\x0eVerifyPasscode\x12!.eolymp.judge.VerifyPasscodeInput\x1a\".eolymp.judge.VerifyPasscodeOutput\"W\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02(\"&/contests/{contest_id}/verify-passcode\x12\xb3\x01\n\rEnterPasscode\x12 .eolymp.judge.EnterPasscodeInput\x1a!.eolymp.judge.EnterPasscodeOutput\"]\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\x82\xd3\xe4\x93\x02\'\"%/contests/{contest_id}/enter-passcode\x12\xc5\x01\n\rResetPasscode\x12 .eolymp.judge.ResetPasscodeInput\x1a!.eolymp.judge.ResetPasscodeOutput\"o\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02?\"=/contests/{contest_id}/participants/{participant_id}/passcode\x12\xbf\x01\n\x0bSetPasscode\x12\x1e.eolymp.judge.SetPasscodeInput\x1a\x1f.eolymp.judge.SetPasscodeOutput\"o\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02?\x1a=/contests/{contest_id}/participants/{participant_id}/passcode\x12\xc8\x01\n\x0eRemovePasscode\x12!.eolymp.judge.RemovePasscodeInput\x1a\".eolymp.judge.RemovePasscodeOutput\"o\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02?*=/contests/{contest_id}/participants/{participant_id}/passcode\x12\xcf\x01\n\x10\x43reateSubmission\x12#.eolymp.judge.CreateSubmissionInput\x1a$.eolymp.judge.CreateSubmissionOutput\"p\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\n\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\x82\xd3\xe4\x93\x02:\"8/contests/{contest_id}/problems/{problem_id}/submissions\x12\xaf\x01\n\x0fListSubmissions\x12\".eolymp.judge.ListSubmissionsInput\x1a#.eolymp.judge.ListSubmissionsOutput\"S\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02$\x12\"/contests/{contest_id}/submissions\x12\xc8\x01\n\x12\x44\x65scribeSubmission\x12%.eolymp.judge.DescribeSubmissionInput\x1a&.eolymp.judge.DescribeSubmissionOutput\"c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x34\x12\x32/contests/{contest_id}/submissions/{submission_id}\x12x\n\x0fWatchSubmission\x12\".eolymp.judge.WatchSubmissionInput\x1a#.eolymp.judge.WatchSubmissionOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x12\xca\x01\n\x10RetestSubmission\x12#.eolymp.judge.RetestSubmissionInput\x1a$.eolymp.judge.RetestSubmissionOutput\"k\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02;\"9/contests/{contest_id}/submissions/{submission_id}/retest\x12\xc3\x01\n\x10\x44\x65leteSubmission\x12#.eolymp.judge.DeleteSubmissionInput\x1a$.eolymp.judge.DeleteSubmissionOutput\"d\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x34*2/contests/{contest_id}/submissions/{submission_id}\x12\xce\x01\n\x11RestoreSubmission\x12$.eolymp.judge.RestoreSubmissionInput\x1a%.eolymp.judge.RestoreSubmissionOutput\"l\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02<\":/contests/{contest_id}/submissions/{submission_id}/restore\x12\xbb\x01\n\x12\x43reateAnnouncement\x12%.eolymp.judge.CreateAnnouncementInput\x1a&.eolymp.judge.CreateAnnouncementOutput\"V\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02&\"$/contests/{contest_id}/announcements\x12\xcd\x01\n\x12UpdateAnnouncement\x12%.eolymp.judge.UpdateAnnouncementInput\x1a&.eolymp.judge.UpdateAnnouncementOutput\"h\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x38\"6/contests/{contest_id}/announcements/{announcement_id}\x12\xcd\x01\n\x12\x44\x65leteAnnouncement\x12%.eolymp.judge.DeleteAnnouncementInput\x1a&.eolymp.judge.DeleteAnnouncementOutput\"h\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02\x38*6/contests/{contest_id}/announcements/{announcement_id}\x12\xcb\x01\n\x10ReadAnnouncement\x12#.eolymp.judge.ReadAnnouncementInput\x1a$.eolymp.judge.ReadAnnouncementOutput\"l\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02=\";/contests/{contest_id}/announcements/{announcement_id}/read\x12\xd2\x01\n\x14\x44\x65scribeAnnouncement\x12\'.eolymp.judge.DescribeAnnouncementInput\x1a(.eolymp.judge.DescribeAnnouncementOutput\"g\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02\x38\x12\x36/contests/{contest_id}/announcements/{announcement_id}\x12\xeb\x01\n\x1a\x44\x65scribeAnnouncementStatus\x12-.eolymp.judge.DescribeAnnouncementStatusInput\x1a..eolymp.judge.DescribeAnnouncementStatusOutput\"n\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02?\x12=/contests/{contest_id}/announcements/{announcement_id}/status\x12\xb7\x01\n\x11ListAnnouncements\x12$.eolymp.judge.ListAnnouncementsInput\x1a%.eolymp.judge.ListAnnouncementsOutput\"U\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02&\x12$/contests/{contest_id}/announcements\x12\x9a\x01\n\x0fIntrospectScore\x12\".eolymp.judge.IntrospectScoreInput\x1a#.eolymp.judge.IntrospectScoreOutput\">\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02)\x12\'/contests/{contest_id}/introspect/score\x12\xc2\x01\n\rDescribeScore\x12 .eolymp.judge.DescribeScoreInput\x1a!.eolymp.judge.DescribeScoreOutput\"l\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02<\x12:/contests/{contest_id}/participants/{participant_id}/score\x12\xbd\x01\n\x0bImportScore\x12\x1e.eolymp.judge.ImportScoreInput\x1a\x1f.eolymp.judge.ImportScoreOutput\"m\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02=\";/contests/{contest_id}/participants/{participant_id}/scores\x12\xbd\x01\n\x0b\x45xportScore\x12\x1e.eolymp.judge.ExportScoreInput\x1a\x1f.eolymp.judge.ExportScoreOutput\"m\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02=\x12;/contests/{contest_id}/participants/{participant_id}/scores\x12\x9d\x01\n\nListResult\x12\x1d.eolymp.judge.ListResultInput\x1a\x1e.eolymp.judge.ListResultOutput\"P\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xc8\x01\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02 \x12\x1e/contests/{contest_id}/results\x12\xa3\x01\n\x0cRebuildScore\x12\x1f.eolymp.judge.RebuildScoreInput\x1a .eolymp.judge.RebuildScoreOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02 \"\x1e/contests/{contest_id}/rebuild\x12\xab\x01\n\x0eListActivities\x12!.eolymp.judge.ListActivitiesInput\x1a\".eolymp.judge.ListActivitiesOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\x82\xd3\xe4\x93\x02#\x12!/contests/{contest_id}/activities\x12\x91\x01\n\x14\x44\x65scribeContestUsage\x12\'.eolymp.judge.DescribeContestUsageInput\x1a(.eolymp.judge.DescribeContestUsageOutput\"&\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x11\x12\x0f/usage/contestsB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.judge_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_JUDGE'].methods_by_name['CreateContest']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['CreateContest']._serialized_options = b'\352\342\n\013\365\342\n\n\327\243=\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\013\"\t/contests'
  _globals['_JUDGE'].methods_by_name['DeleteContest']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DeleteContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\030*\026/contests/{contest_id}'
  _globals['_JUDGE'].methods_by_name['UpdateContest']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['UpdateContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\030\032\026/contests/{contest_id}'
  _globals['_JUDGE'].methods_by_name['DescribeContest']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DescribeContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\030\022\026/contests/{contest_id}'
  _globals['_JUDGE'].methods_by_name['ListContests']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ListContests']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\013\022\t/contests'
  _globals['_JUDGE'].methods_by_name['OpenContest']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['OpenContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\035\"\033/contests/{contest_id}/open'
  _globals['_JUDGE'].methods_by_name['CloseContest']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['CloseContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\036\"\034/contests/{contest_id}/close'
  _globals['_JUDGE'].methods_by_name['SuspendContest']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['SuspendContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002 \"\036/contests/{contest_id}/suspend'
  _globals['_JUDGE'].methods_by_name['FreezeContest']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['FreezeContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\037\"\035/contests/{contest_id}/freeze'
  _globals['_JUDGE'].methods_by_name['ResumeContest']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ResumeContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002\037\"\035/contests/{contest_id}/resume'
  _globals['_JUDGE'].methods_by_name['ImportProblem']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ImportProblem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002!\"\037/contests/{contest_id}/problems'
  _globals['_JUDGE'].methods_by_name['SyncProblem']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['SyncProblem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\0023\"1/contests/{contest_id}/problems/{problem_id}/sync'
  _globals['_JUDGE'].methods_by_name['UpdateProblem']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['UpdateProblem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002.\",/contests/{contest_id}/problems/{problem_id}'
  _globals['_JUDGE'].methods_by_name['ListProblems']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ListProblems']._serialized_options = b'\352\342\n\013\365\342\n\000\000@@\370\342\n\n\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002!\022\037/contests/{contest_id}/problems'
  _globals['_JUDGE'].methods_by_name['DescribeProblem']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DescribeProblem']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002.\022,/contests/{contest_id}/problems/{problem_id}'
  _globals['_JUDGE'].methods_by_name['DescribeCodeTemplate']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DescribeCodeTemplate']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002F\022D/contests/{contest_id}/problems/{problem_id}/templates/{template_id}'
  _globals['_JUDGE'].methods_by_name['LookupCodeTemplate']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['LookupCodeTemplate']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002>\022</contests/{contest_id}/problems/{problem_id}/lookup-template'
  _globals['_JUDGE'].methods_by_name['ListStatements']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ListStatements']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\0029\0227/contests/{contest_id}/problems/{problem_id}/statements'
  _globals['_JUDGE'].methods_by_name['ListAttachments']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ListAttachments']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002:\0228/contests/{contest_id}/problems/{problem_id}/attachments'
  _globals['_JUDGE'].methods_by_name['ListExamples']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ListExamples']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\0027\0225/contests/{contest_id}/problems/{problem_id}/examples'
  _globals['_JUDGE'].methods_by_name['DeleteProblem']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DeleteProblem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002.*,/contests/{contest_id}/problems/{problem_id}'
  _globals['_JUDGE'].methods_by_name['RetestProblem']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['RetestProblem']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\0025\0223/contests/{contest_id}/problems/{problem_id}/retest'
  _globals['_JUDGE'].methods_by_name['AssignParticipant']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['AssignParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002%\"#/contests/{contest_id}/participants'
  _globals['_JUDGE'].methods_by_name['EnableParticipant']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['EnableParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002=\";/contests/{contest_id}/participants/{participant_id}/enable'
  _globals['_JUDGE'].methods_by_name['DisableParticipant']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DisableParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002>\"</contests/{contest_id}/participants/{participant_id}/disable'
  _globals['_JUDGE'].methods_by_name['UpdateParticipant']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['UpdateParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\0026\0324/contests/{contest_id}/participants/{participant_id}'
  _globals['_JUDGE'].methods_by_name['DeleteParticipant']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DeleteParticipant']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\0026*4/contests/{contest_id}/participants/{participant_id}'
  _globals['_JUDGE'].methods_by_name['ListParticipants']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ListParticipants']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002%\022#/contests/{contest_id}/participants'
  _globals['_JUDGE'].methods_by_name['DescribeParticipant']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DescribeParticipant']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\0026\0224/contests/{contest_id}/participants/{participant_id}'
  _globals['_JUDGE'].methods_by_name['DescribeViewer']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DescribeViewer']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002#\022!/contests/{contest_id}/introspect'
  _globals['_JUDGE'].methods_by_name['JoinContest']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['JoinContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\003\202\323\344\223\002\035\"\033/contests/{contest_id}/join'
  _globals['_JUDGE'].methods_by_name['StartContest']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['StartContest']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\003\202\343\n\035\212\343\n\031judge:contest:participate\202\323\344\223\002\036\"\034/contests/{contest_id}/start'
  _globals['_JUDGE'].methods_by_name['VerifyPasscode']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['VerifyPasscode']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002(\"&/contests/{contest_id}/verify-passcode'
  _globals['_JUDGE'].methods_by_name['EnterPasscode']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['EnterPasscode']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\035\212\343\n\031judge:contest:participate\202\323\344\223\002\'\"%/contests/{contest_id}/enter-passcode'
  _globals['_JUDGE'].methods_by_name['ResetPasscode']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ResetPasscode']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002?\"=/contests/{contest_id}/participants/{participant_id}/passcode'
  _globals['_JUDGE'].methods_by_name['SetPasscode']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['SetPasscode']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002?\032=/contests/{contest_id}/participants/{participant_id}/passcode'
  _globals['_JUDGE'].methods_by_name['RemovePasscode']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['RemovePasscode']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002?*=/contests/{contest_id}/participants/{participant_id}/passcode'
  _globals['_JUDGE'].methods_by_name['CreateSubmission']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['CreateSubmission']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\n\202\343\n\035\212\343\n\031judge:contest:participate\202\323\344\223\002:\"8/contests/{contest_id}/problems/{problem_id}/submissions'
  _globals['_JUDGE'].methods_by_name['ListSubmissions']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ListSubmissions']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002$\022\"/contests/{contest_id}/submissions'
  _globals['_JUDGE'].methods_by_name['DescribeSubmission']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DescribeSubmission']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\0024\0222/contests/{contest_id}/submissions/{submission_id}'
  _globals['_JUDGE'].methods_by_name['WatchSubmission']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['WatchSubmission']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _globals['_JUDGE'].methods_by_name['RetestSubmission']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['RetestSubmission']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002;\"9/contests/{contest_id}/submissions/{submission_id}/retest'
  _globals['_JUDGE'].methods_by_name['DeleteSubmission']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DeleteSubmission']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\0024*2/contests/{contest_id}/submissions/{submission_id}'
  _globals['_JUDGE'].methods_by_name['RestoreSubmission']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['RestoreSubmission']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002<\":/contests/{contest_id}/submissions/{submission_id}/restore'
  _globals['_JUDGE'].methods_by_name['CreateAnnouncement']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['CreateAnnouncement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002&\"$/contests/{contest_id}/announcements'
  _globals['_JUDGE'].methods_by_name['UpdateAnnouncement']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['UpdateAnnouncement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\0028\"6/contests/{contest_id}/announcements/{announcement_id}'
  _globals['_JUDGE'].methods_by_name['DeleteAnnouncement']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DeleteAnnouncement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\0028*6/contests/{contest_id}/announcements/{announcement_id}'
  _globals['_JUDGE'].methods_by_name['ReadAnnouncement']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ReadAnnouncement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002=\";/contests/{contest_id}/announcements/{announcement_id}/read'
  _globals['_JUDGE'].methods_by_name['DescribeAnnouncement']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DescribeAnnouncement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\0028\0226/contests/{contest_id}/announcements/{announcement_id}'
  _globals['_JUDGE'].methods_by_name['DescribeAnnouncementStatus']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DescribeAnnouncementStatus']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002?\022=/contests/{contest_id}/announcements/{announcement_id}/status'
  _globals['_JUDGE'].methods_by_name['ListAnnouncements']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ListAnnouncements']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002&\022$/contests/{contest_id}/announcements'
  _globals['_JUDGE'].methods_by_name['IntrospectScore']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['IntrospectScore']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002)\022\'/contests/{contest_id}/introspect/score'
  _globals['_JUDGE'].methods_by_name['DescribeScore']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DescribeScore']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002<\022:/contests/{contest_id}/participants/{participant_id}/score'
  _globals['_JUDGE'].methods_by_name['ImportScore']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ImportScore']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002=\";/contests/{contest_id}/participants/{participant_id}/scores'
  _globals['_JUDGE'].methods_by_name['ExportScore']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ExportScore']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002=\022;/contests/{contest_id}/participants/{participant_id}/scores'
  _globals['_JUDGE'].methods_by_name['ListResult']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ListResult']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\310\001\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002 \022\036/contests/{contest_id}/results'
  _globals['_JUDGE'].methods_by_name['RebuildScore']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['RebuildScore']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002 \"\036/contests/{contest_id}/rebuild'
  _globals['_JUDGE'].methods_by_name['ListActivities']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['ListActivities']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\026\212\343\n\022judge:contest:read\202\323\344\223\002#\022!/contests/{contest_id}/activities'
  _globals['_JUDGE'].methods_by_name['DescribeContestUsage']._loaded_options = None
  _globals['_JUDGE'].methods_by_name['DescribeContestUsage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\021\022\017/usage/contests'
  _globals['_JUDGE']._serialized_start=405
  _globals['_JUDGE']._serialized_end=11234
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/editorial.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/atlas/editorial.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/atlas/editorial.proto\x12\x0c\x65olymp.atlas\x1a\x18\x65olymp/ecm/content.proto\"\xfc\x02\n\tEditorial\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x03 \x01(\t\x12\x11\n\tautomatic\x18\x08 \x01(\x08\x12\r\n\x05\x64raft\x18\n \x01(\x08\x12$\n\x07\x63ontent\x18\x06 \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x15\n\rdownload_link\x18\x07 \x01(\t\x12\x11\n\tauthor_id\x18g \x01(\t\"<\n\x05\x45xtra\x12\x0c\n\x08NO_EXTRA\x10\x00\x12\x12\n\x0e\x43ONTENT_RENDER\x10\x01\x12\x11\n\rCONTENT_VALUE\x10\x02\"\xa2\x01\n\x05Patch\x12\x11\n\rUNKNOWN_PATCH\x10\x00\x12\r\n\tPATCH_ALL\x10\x01\x12\x10\n\x0cPATCH_LOCALE\x10\x02\x12\x13\n\x0fPATCH_AUTOMATIC\x10\x03\x12\x0f\n\x0bPATCH_DRAFT\x10\x04\x12\x11\n\rPATCH_CONTENT\x10\x05\x12\x17\n\x13PATCH_DOWNLOAD_LINK\x10\x06\x12\x13\n\x0fPATCH_AUTHOR_ID\x10\x07\x42-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.editorial_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_EDITORIAL']._serialized_start=73
  _globals['_EDITORIAL']._serialized_end=453
  _globals['_EDITORIAL_EXTRA']._serialized_start=228
  _globals['_EDITORIAL_EXTRA']._serialized_end=288
  _globals['_EDITORIAL_PATCH']._serialized_start=291
  _globals['_EDITORIAL_PATCH']._serialized_end=453
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/cognito/user.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/cognito/user.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x65olymp/cognito/user.proto\x12\x0e\x65olymp.cognito\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa1\x04\n\x04User\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12\x0c\n\x04rank\x18) \x01(\r\x12\x32\n\nrank_trend\x18* \x01(\x0e\x32\x1e.eolymp.cognito.User.RankTrend\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0f\n\x07picture\x18\x0b \x01(\t\x12\x0f\n\x07\x63ompany\x18\x0c \x01(\t\x12\x12\n\noccupation\x18\r \x01(\t\x12\x0f\n\x07\x63ountry\x18\x15 \x01(\t\x12\x0c\n\x04\x63ity\x18\x16 \x01(\t\x12\x14\n\x0c\x65mail_status\x18  \x01(\t\x12\x10\n\x08\x62irthday\x18! \x01(\t\x12\x31\n\rregistered_on\x18\" \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rlast_activity\x18# \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x13username_changed_on\x18$ \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x13password_changed_on\x18% \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06locale\x18( \x01(\t\"\'\n\tRankTrend\x12\x08\n\x04NONE\x10\x00\x12\x06\n\x02UP\x10\x01\x12\x08\n\x04\x44OWN\x10\x02\x42\x31Z/github.com/eolymp/go-sdk/eolymp/cognito;cognitob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.cognito.user_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/cognito;cognito'
  _globals['_USER']._serialized_start=79
  _globals['_USER']._serialized_end=624
  _globals['_USER_RANKTREND']._serialized_start=585
  _globals['_USER_RANKTREND']._serialized_end=624
# @@protoc_insertion_point(module_scope)



from eolymp.ecm import content_pb2 as _content_pb2
from eolymp.ecm import node_pb2 as _node_pb2
from eolymp.wellknown import link_pb2 as _link_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Post(_message.Message):
    __slots__ = ("id", "url", "source_id", "source_url", "draft", "public", "featured", "pinned", "moderation", "user_id", "member_id", "created_at", "published_at", "updated_at", "type_id", "locale", "title", "image_url", "content", "preview", "vote", "vote_count", "reply_count", "labels", "links")
    class Moderation(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_MODERATION: _ClassVar[Post.Moderation]
        PENDING: _ClassVar[Post.Moderation]
        IN_REVIEW: _ClassVar[Post.Moderation]
        APPROVED: _ClassVar[Post.Moderation]
        REJECTED: _ClassVar[Post.Moderation]
    UNKNOWN_MODERATION: Post.Moderation
    PENDING: Post.Moderation
    IN_REVIEW: Post.Moderation
    APPROVED: Post.Moderation
    REJECTED: Post.Moderation
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_EXTRA: _ClassVar[Post.Extra]
        CONTENT_VALUE: _ClassVar[Post.Extra]
        CONTENT_RENDER: _ClassVar[Post.Extra]
        PREVIEW: _ClassVar[Post.Extra]
        VOTE: _ClassVar[Post.Extra]
    UNKNOWN_EXTRA: Post.Extra
    CONTENT_VALUE: Post.Extra
    CONTENT_RENDER: Post.Extra
    PREVIEW: Post.Extra
    VOTE: Post.Extra
    class Translation(_message.Message):
        __slots__ = ("id", "locale", "content", "labels", "automatic")
        ID_FIELD_NUMBER: _ClassVar[int]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        CONTENT_FIELD_NUMBER: _ClassVar[int]
        LABELS_FIELD_NUMBER: _ClassVar[int]
        AUTOMATIC_FIELD_NUMBER: _ClassVar[int]
        id: str
        locale: str
        content: _content_pb2.Content
        labels: _containers.RepeatedScalarFieldContainer[str]
        automatic: bool
        def __init__(self, id: _Optional[str] = ..., locale: _Optional[str] = ..., content: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., labels: _Optional[_Iterable[str]] = ..., automatic: bool = ...) -> None: ...
    class Image(_message.Message):
        __slots__ = ("src", "width", "height")
        SRC_FIELD_NUMBER: _ClassVar[int]
        WIDTH_FIELD_NUMBER: _ClassVar[int]
        HEIGHT_FIELD_NUMBER: _ClassVar[int]
        CLASS_FIELD_NUMBER: _ClassVar[int]
        src: str
        width: int
        height: int
        def __init__(self, src: _Optional[str] = ..., width: _Optional[int] = ..., height: _Optional[int] = ..., **kwargs) -> None: ...
    class Preview(_message.Message):
        __slots__ = ("title", "image", "content")
        TITLE_FIELD_NUMBER: _ClassVar[int]
        IMAGE_FIELD_NUMBER: _ClassVar[int]
        CONTENT_FIELD_NUMBER: _ClassVar[int]
        title: str
        image: Post.Image
        content: _node_pb2.Node
        def __init__(self, title: _Optional[str] = ..., image: _Optional[_Union[Post.Image, _Mapping]] = ..., content: _Optional[_Union[_node_pb2.Node, _Mapping]] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_URL_FIELD_NUMBER: _ClassVar[int]
    DRAFT_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_FIELD_NUMBER: _ClassVar[int]
    FEATURED_FIELD_NUMBER: _ClassVar[int]
    PINNED_FIELD_NUMBER: _ClassVar[int]
    MODERATION_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    PUBLISHED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    IMAGE_URL_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    PREVIEW_FIELD_NUMBER: _ClassVar[int]
    VOTE_FIELD_NUMBER: _ClassVar[int]
    VOTE_COUNT_FIELD_NUMBER: _ClassVar[int]
    REPLY_COUNT_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    LINKS_FIELD_NUMBER: _ClassVar[int]
    id: str
    url: str
    source_id: str
    source_url: str
    draft: bool
    public: bool
    featured: bool
    pinned: bool
    moderation: Post.Moderation
    user_id: str
    member_id: str
    created_at: _timestamp_pb2.Timestamp
    published_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    type_id: str
    locale: str
    title: str
    image_url: str
    content: _content_pb2.Content
    preview: Post.Preview
    vote: int
    vote_count: int
    reply_count: int
    labels: _containers.RepeatedScalarFieldContainer[str]
    links: _containers.RepeatedCompositeFieldContainer[_link_pb2.Link]
    def __init__(self, id: _Optional[str] = ..., url: _Optional[str] = ..., source_id: _Optional[str] = ..., source_url: _Optional[str] = ..., draft: bool = ..., public: bool = ..., featured: bool = ..., pinned: bool = ..., moderation: _Optional[_Union[Post.Moderation, str]] = ..., user_id: _Optional[str] = ..., member_id: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., published_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., type_id: _Optional[str] = ..., locale: _Optional[str] = ..., title: _Optional[str] = ..., image_url: _Optional[str] = ..., content: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., preview: _Optional[_Union[Post.Preview, _Mapping]] = ..., vote: _Optional[int] = ..., vote_count: _Optional[int] = ..., reply_count: _Optional[int] = ..., labels: _Optional[_Iterable[str]] = ..., links: _Optional[_Iterable[_Union[_link_pb2.Link, _Mapping]]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Link(_message.Message):
    __slots__ = ("rel", "ref", "type")
    REL_FIELD_NUMBER: _ClassVar[int]
    REF_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    rel: str
    ref: str
    type: str
    def __init__(self, rel: _Optional[str] = ..., ref: _Optional[str] = ..., type: _Optional[str] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.judge import scoreboard_pb2 as _scoreboard_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DescribeScoreboardInput(_message.Message):
    __slots__ = ("round_id",)
    ROUND_ID_FIELD_NUMBER: _ClassVar[int]
    round_id: str
    def __init__(self, round_id: _Optional[str] = ...) -> None: ...

class DescribeScoreboardOutput(_message.Message):
    __slots__ = ("scoreboard",)
    SCOREBOARD_FIELD_NUMBER: _ClassVar[int]
    scoreboard: _scoreboard_pb2.Scoreboard
    def __init__(self, scoreboard: _Optional[_Union[_scoreboard_pb2.Scoreboard, _Mapping]] = ...) -> None: ...

class ListScoreboardRowsInput(_message.Message):
    __slots__ = ("mode", "round_id", "size", "offset", "filters", "sort", "order")
    class Filter(_message.Message):
        __slots__ = ("unofficial", "disqualified")
        UNOFFICIAL_FIELD_NUMBER: _ClassVar[int]
        DISQUALIFIED_FIELD_NUMBER: _ClassVar[int]
        unofficial: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        disqualified: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        def __init__(self, unofficial: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ..., disqualified: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ...) -> None: ...
    MODE_FIELD_NUMBER: _ClassVar[int]
    ROUND_ID_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    mode: _scoreboard_pb2.Scoreboard.Mode
    round_id: str
    size: int
    offset: int
    filters: ListScoreboardRowsInput.Filter
    sort: str
    order: _direction_pb2.Direction
    def __init__(self, mode: _Optional[_Union[_scoreboard_pb2.Scoreboard.Mode, str]] = ..., round_id: _Optional[str] = ..., size: _Optional[int] = ..., offset: _Optional[int] = ..., filters: _Optional[_Union[ListScoreboardRowsInput.Filter, _Mapping]] = ..., sort: _Optional[str] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ...) -> None: ...

class ListScoreboardRowsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_scoreboard_pb2.Scoreboard.Row]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_scoreboard_pb2.Scoreboard.Row, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/helpdesk/support.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/helpdesk/support.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.helpdesk import auto_reply_service_pb2 as eolymp_dot_helpdesk_dot_auto__reply__service__pb2
from eolymp.helpdesk import ticket_service_pb2 as eolymp_dot_helpdesk_dot_ticket__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/helpdesk/support.proto\x12\x0f\x65olymp.helpdesk\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a(eolymp/helpdesk/auto_reply_service.proto\x1a$eolymp/helpdesk/ticket_service.proto2\xfd\x1a\n\x07Support\x12\x9e\x01\n\x0c\x43reateTicket\x12\".eolymp.helpdesk.CreateTicketInput\x1a#.eolymp.helpdesk.CreateTicketOutput\"E\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x13\"\x11/helpdesk/tickets\x12\xaa\x01\n\x0cUpdateTicket\x12\".eolymp.helpdesk.UpdateTicketInput\x1a#.eolymp.helpdesk.UpdateTicketOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x1f\x1a\x1d/helpdesk/tickets/{ticket_id}\x12\xaa\x01\n\x0c\x44\x65leteTicket\x12\".eolymp.helpdesk.DeleteTicketInput\x1a#.eolymp.helpdesk.DeleteTicketOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x1f*\x1d/helpdesk/tickets/{ticket_id}\x12\xaf\x01\n\x0e\x44\x65scribeTicket\x12$.eolymp.helpdesk.DescribeTicketInput\x1a%.eolymp.helpdesk.DescribeTicketOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x18\x8a\xe3\n\x14helpdesk:ticket:read\x82\xd3\xe4\x93\x02\x1f\x12\x1d/helpdesk/tickets/{ticket_id}\x12\x9a\x01\n\x0bListTickets\x12!.eolymp.helpdesk.ListTicketsInput\x1a\".eolymp.helpdesk.ListTicketsOutput\"D\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x18\x8a\xe3\n\x14helpdesk:ticket:read\x82\xd3\xe4\x93\x02\x13\x12\x11/helpdesk/tickets\x12\xb5\x01\n\rApproveTicket\x12#.eolymp.helpdesk.ApproveTicketInput\x1a$.eolymp.helpdesk.ApproveTicketOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\'\"%/helpdesk/tickets/{ticket_id}/approve\x12\xb1\x01\n\x0cRejectTicket\x12\".eolymp.helpdesk.RejectTicketInput\x1a#.eolymp.helpdesk.RejectTicketOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02&\"$/helpdesk/tickets/{ticket_id}/reject\x12\xad\x01\n\x0b\x43loseTicket\x12!.eolymp.helpdesk.CloseTicketInput\x1a\".eolymp.helpdesk.CloseTicketOutput\"W\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02%\"#/helpdesk/tickets/{ticket_id}/close\x12\xad\x01\n\nAddComment\x12 .eolymp.helpdesk.AddCommentInput\x1a!.eolymp.helpdesk.AddCommentOutput\"Z\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02(\"&/helpdesk/tickets/{ticket_id}/comments\x12\xc3\x01\n\rUpdateComment\x12#.eolymp.helpdesk.UpdateCommentInput\x1a$.eolymp.helpdesk.UpdateCommentOutput\"g\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x35\x1a\x33/helpdesk/tickets/{ticket_id}/comments/{comment_id}\x12\xc3\x01\n\rDeleteComment\x12#.eolymp.helpdesk.DeleteCommentInput\x1a$.eolymp.helpdesk.DeleteCommentOutput\"g\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x35*3/helpdesk/tickets/{ticket_id}/comments/{comment_id}\x12\xb2\x01\n\x0cListComments\x12\".eolymp.helpdesk.ListCommentsInput\x1a#.eolymp.helpdesk.ListCommentsOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x18\x8a\xe3\n\x14helpdesk:ticket:read\x82\xd3\xe4\x93\x02(\x12&/helpdesk/tickets/{ticket_id}/comments\x12\xc9\x01\n\x0f\x44\x65scribeComment\x12%.eolymp.helpdesk.DescribeCommentInput\x1a&.eolymp.helpdesk.DescribeCommentOutput\"g\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x35\x12\x33/helpdesk/tickets/{ticket_id}/comments/{comment_id}\x12\xaf\x01\n\x0f\x43reateAutoReply\x12%.eolymp.helpdesk.CreateAutoReplyInput\x1a&.eolymp.helpdesk.CreateAutoReplyOutput\"M\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x1d\x8a\xe3\n\x19helpdesk:auto-reply:write\x82\xd3\xe4\x93\x02\x17\"\x15/helpdesk/autoreplies\x12\xba\x01\n\x0fUpdateAutoReply\x12%.eolymp.helpdesk.UpdateAutoReplyInput\x1a&.eolymp.helpdesk.UpdateAutoReplyOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x1d\x8a\xe3\n\x19helpdesk:auto-reply:write\x82\xd3\xe4\x93\x02\"\x1a /helpdesk/autoreplies/{reply_id}\x12\xba\x01\n\x0f\x44\x65leteAutoReply\x12%.eolymp.helpdesk.DeleteAutoReplyInput\x1a&.eolymp.helpdesk.DeleteAutoReplyOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x1d\x8a\xe3\n\x19helpdesk:auto-reply:write\x82\xd3\xe4\x93\x02\"* /helpdesk/autoreplies/{reply_id}\x12\xae\x01\n\x0fListAutoReplies\x12%.eolymp.helpdesk.ListAutoRepliesInput\x1a&.eolymp.helpdesk.ListAutoRepliesOutput\"L\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1c\x8a\xe3\n\x18helpdesk:auto-reply:read\x82\xd3\xe4\x93\x02\x17\x12\x15/helpdesk/autoreplies\x12\xc0\x01\n\x11\x44\x65scribeAutoReply\x12\'.eolymp.helpdesk.DescribeAutoReplyInput\x1a(.eolymp.helpdesk.DescribeAutoReplyOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1d\x8a\xe3\n\x19helpdesk:auto-reply:write\x82\xd3\xe4\x93\x02\"\x12 /helpdesk/autoreplies/{reply_id}\x12\xae\x01\n\x10UploadAttachment\x12&.eolymp.helpdesk.UploadAttachmentInput\x1a\'.eolymp.helpdesk.UploadAttachmentOutput\"I\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15helpdesk:ticket:write\x82\xd3\xe4\x93\x02\x17\"\x15/helpdesk/attachmentsB3Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdeskb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.helpdesk.support_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdesk'
  _globals['_SUPPORT'].methods_by_name['CreateTicket']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['CreateTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002\023\"\021/helpdesk/tickets'
  _globals['_SUPPORT'].methods_by_name['UpdateTicket']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['UpdateTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002\037\032\035/helpdesk/tickets/{ticket_id}'
  _globals['_SUPPORT'].methods_by_name['DeleteTicket']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['DeleteTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002\037*\035/helpdesk/tickets/{ticket_id}'
  _globals['_SUPPORT'].methods_by_name['DescribeTicket']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['DescribeTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\030\212\343\n\024helpdesk:ticket:read\202\323\344\223\002\037\022\035/helpdesk/tickets/{ticket_id}'
  _globals['_SUPPORT'].methods_by_name['ListTickets']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['ListTickets']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\030\212\343\n\024helpdesk:ticket:read\202\323\344\223\002\023\022\021/helpdesk/tickets'
  _globals['_SUPPORT'].methods_by_name['ApproveTicket']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['ApproveTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002\'\"%/helpdesk/tickets/{ticket_id}/approve'
  _globals['_SUPPORT'].methods_by_name['RejectTicket']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['RejectTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002&\"$/helpdesk/tickets/{ticket_id}/reject'
  _globals['_SUPPORT'].methods_by_name['CloseTicket']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['CloseTicket']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002%\"#/helpdesk/tickets/{ticket_id}/close'
  _globals['_SUPPORT'].methods_by_name['AddComment']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['AddComment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002(\"&/helpdesk/tickets/{ticket_id}/comments'
  _globals['_SUPPORT'].methods_by_name['UpdateComment']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['UpdateComment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\0025\0323/helpdesk/tickets/{ticket_id}/comments/{comment_id}'
  _globals['_SUPPORT'].methods_by_name['DeleteComment']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['DeleteComment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\0025*3/helpdesk/tickets/{ticket_id}/comments/{comment_id}'
  _globals['_SUPPORT'].methods_by_name['ListComments']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['ListComments']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\030\212\343\n\024helpdesk:ticket:read\202\323\344\223\002(\022&/helpdesk/tickets/{ticket_id}/comments'
  _globals['_SUPPORT'].methods_by_name['DescribeComment']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['DescribeComment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\0025\0223/helpdesk/tickets/{ticket_id}/comments/{comment_id}'
  _globals['_SUPPORT'].methods_by_name['CreateAutoReply']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['CreateAutoReply']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\035\212\343\n\031helpdesk:auto-reply:write\202\323\344\223\002\027\"\025/helpdesk/autoreplies'
  _globals['_SUPPORT'].methods_by_name['UpdateAutoReply']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['UpdateAutoReply']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\035\212\343\n\031helpdesk:auto-reply:write\202\323\344\223\002\"\032 /helpdesk/autoreplies/{reply_id}'
  _globals['_SUPPORT'].methods_by_name['DeleteAutoReply']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['DeleteAutoReply']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\035\212\343\n\031helpdesk:auto-reply:write\202\323\344\223\002\"* /helpdesk/autoreplies/{reply_id}'
  _globals['_SUPPORT'].methods_by_name['ListAutoReplies']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['ListAutoReplies']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\034\212\343\n\030helpdesk:auto-reply:read\202\323\344\223\002\027\022\025/helpdesk/autoreplies'
  _globals['_SUPPORT'].methods_by_name['DescribeAutoReply']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['DescribeAutoReply']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\035\212\343\n\031helpdesk:auto-reply:write\202\323\344\223\002\"\022 /helpdesk/autoreplies/{reply_id}'
  _globals['_SUPPORT'].methods_by_name['UploadAttachment']._loaded_options = None
  _globals['_SUPPORT'].methods_by_name['UploadAttachment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025helpdesk:ticket:write\202\323\344\223\002\027\"\025/helpdesk/attachments'
  _globals['_SUPPORT']._serialized_start=230
  _globals['_SUPPORT']._serialized_end=3683
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Printer(_message.Message):
    __slots__ = ("id", "secret", "status", "name")
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_STATUS: _ClassVar[Printer.Status]
        OFFLINE: _ClassVar[Printer.Status]
        READY: _ClassVar[Printer.Status]
        BUSY: _ClassVar[Printer.Status]
    UNKNOWN_STATUS: Printer.Status
    OFFLINE: Printer.Status
    READY: Printer.Status
    BUSY: Printer.Status
    ID_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    id: str
    secret: str
    status: Printer.Status
    name: str
    def __init__(self, id: _Optional[str] = ..., secret: _Optional[str] = ..., status: _Optional[_Union[Printer.Status, str]] = ..., name: _Optional[str] = ...) -> None: ...
